const gitCommands = [
    {
        command: ['git clone <url>'],
        description: 'Cloner un dépôt distant.',
        long_description: `
La commande \`git clone\` est utilisée pour créer une copie locale d'un dépôt Git distant sur votre ordinateur. Cette copie inclut tous les fichiers du projet, ainsi que l'historique complet des commits. C'est généralement la première commande que l'on exécute lorsqu'on souhaite commencer à travailler sur un projet hébergé en ligne.

#### Ce qui se passe lors de l'exécution

Lorsque vous exécutez \`git clone <url>\`, Git réalise plusieurs opérations :

1. **Connexion au dépôt distant** : Git se connecte au dépôt spécifié par l'URL. Dans notre cas, ce sera principalement sur la plateforme GitLab de l'université (\`git.unistra.fr\`).
  
2. **Téléchargement des données** : Git copie l'intégralité du contenu du dépôt, y compris tous les fichiers, les dossiers, les branches, et l'historique des commits. Vous obtenez ainsi une copie locale complète.

3. **Création d'un nouveau dossier** : Par défaut, Git crée un nouveau dossier portant le nom du projet à l'endroit où vous avez exécuté la commande. Ce dossier contient tous les fichiers du projet.

4. **Configuration du dépôt local** : Une fois le téléchargement terminé, Git configure votre dépôt local pour qu'il soit connecté au dépôt distant. Cela permet de synchroniser vos modifications avec le dépôt original en utilisant les commandes \`git push\` et \`git pull\`.

#### Exemple d'utilisation

\`\`\`bash
$ git clone git@git.unistra.fr:mon-username/mon-projet.git
\`\`\`

- **Explication** :
  - Cette commande crée un dossier \`mon-projet\` dans le répertoire actuel.
  - Ce dossier contient tous les fichiers et l'historique du projet \`mon-projet\` hébergé sur \`git.unistra.fr\`.
  - Vous pouvez maintenant naviguer dans ce dossier avec \`cd mon-projet\` et commencer à travailler sur le projet.

#### Comment récupérer l'URL d'un dépôt sur \`git.unistra.fr\`

1. **Accédez à votre projet GitLab** :
   - Ouvrez votre navigateur et connectez-vous sur [https://git.unistra.fr](https://git.unistra.fr).
   - Authentifiez-vous avec vos identifiants de l'université.

2. **Naviguez vers le projet** :
   - Cliquez sur le projet que vous souhaitez cloner.

3. **Copiez l'URL HTTPS** :
   - Sur la page d'accueil du projet, cliquez sur le bouton **"Clone"** (généralement situé en haut à droite).
   - Vous verrez deux options : **HTTPS** et **SSH**.
   - Copiez l'URL sous l'option **SSH** (elle ressemble à \`git@git.unistra.fr:mon-username/mon-projet.git\`).

4. **Utilisez cette URL dans la commande** :
   - Collez l'URL après \`git clone\` dans votre terminal.

#### Exemple avec GitLab de l'université

\`\`\`bash
$ git clone git@git.unistra.fr:mon-username/mon-projet.git
\`\`\`

Pour fonctionner, vous devez avoir renseigner votre clé SSH sur GitLab. Allez dans les paramètres de votre compte pour ajouter votre clé publique SSH.

#### Résultat attendu

Après avoir exécuté \`git clone\` :

- Vous obtiendrez un dossier local contenant tous les fichiers du projet.
- Vous pourrez commencer à travailler sur ce projet, créer de nouvelles branches, effectuer des commits, et les pousser sur le dépôt distant.
- Vous serez en mesure de collaborer avec d'autres étudiants en utilisant les fonctionnalités de merge requests, issues, etc., directement sur GitLab.

Cela permet une collaboration efficace en garantissant que chaque membre de l'équipe dispose d'une copie complète et synchronisée du projet.
`,
        example: 'git clone git@git.unistra.fr:mon-username/mon-projet.git',
        result: 'Le projet est cloné dans un nouveau dossier nommé "mon-projet".',
        tag: 'création',
    },
    {
        command: ['git config --global user.name "Votre Nom"'],
        description: 'Configurer le nom d’utilisateur Git.',
        example: 'git config --global user.name "Jean Dupont"',
        result: 'Le nom d’utilisateur est configuré pour tous les dépôts Git sur votre machine.',
        tag: 'création',
    },
    {
        command: ['git config --global user.email "user@etu.unistra.fr"'],
        description: 'Configurer l’adresse email Git.',
        example: 'git config --global user.email "user@etu.unistra.fr"',
        result: 'L’adresse email est configurée pour tous les dépôts Git sur votre machine.',
        tag: 'création',
    },
    {
        command: ['git status'],
        description: 'Afficher l’état des fichiers dans le répertoire de travail.',
        example: 'git status',
        result: 'Liste des fichiers modifiés, ajoutés ou supprimés par rapport à la dernière validation.',
        tag: 'basique',
    },
    {
        command: ['git add <fichier>', 'git add <dossier>'],
        description: 'Dit à git que l\'on souhaite sauvegarder ce fichier ou ce dossier.',
        example: 'git add .',
        result: 'Ajoute tout les fichiers du dossier courant.',
        tag: 'basique',
    }, 
    {
        command: ['git commit -am "message"'],
        description: 'Enregistrer les modifications des fichiers suivis avec un message.',
        long_description: 'Les fichiers qu\'on à ajouté avec \'git add\' dans le passé sont sauvegarder localement. On pourra retrouver leur contenu à tout moment. Cependant, ils ne sont pas sauvegarder sur le serveur distant ou partagés avec d\'autre. Pour cela il faut "pousser" les modifications avec la command "git push".',
        example: 'git commit -am "résolution de TP1"',
        result: 'Un nouveau commit est créé avec le message "résolution de TP1".',
        tag: 'basique',
    },
    {
        command: ['git push'],
        description: 'Envoyer les modifications locales vers le dépôt distant.',
        example: 'git push origin main',
        result: 'Les modifications sont envoyées à la branche "main" du dépôt distant.',
        tag: 'basique',
    },
    {
        command: ['git pull'],
        description: 'Récupérer les modifications depuis le dépôt distant.',
        example: 'git pull origin main',
        result: 'Les modifications de la branche "main" sont fusionnées dans votre branche locale.',
        tag: 'basique',
    },
    {
        command: ['git log'],
        description: 'Afficher l’historique des commits.',
        long_description: `
La commande \`git log\` permet d\'afficher l\'historique des commits dans le dépôt. Pour la rendre plus jolie, on peut ajouter des options mais pour éviter de le faire à chaque fois, on peut créer un alias avec la commande suivante : \`git config --global alias.lg "log --graph --abbrev-commit --decorate --format=format:'%C(bold blue)%h%C(reset) - %C(bold green)(%ar)%C(reset) %C(white)%s%C(reset) %C(dim white)- %an%C(reset)%C(auto)%d%C(reset)' --all"\`

Ensuite, on peut utiliser la commande \`git lg\` pour afficher l'historique des commits de manière plus lisible.
    `,
        example: 'git log',
        result: 'Liste des commits avec leur auteur, date et message.',
        tag: 'basique',
    },
    {
        common: 'Gestion des conflits',
        command: ['git pull','git merge'],
        description: 'Résoudre les conflits lors de la fusion des branches ou lors de la récupération des modifications.',
        long_description: `
Lorsque vous fusionnez des branches ou récupérez des modifications depuis le dépôt distant (avec \`git pull\`), il peut arriver que Git détecte des conflits entre les différentes versions des fichiers. Ces conflits surviennent lorsque les mêmes parties d'un fichier ont été modifiées de manière incompatible dans les branches en cours de fusion.

#### Comment résoudre les conflits

1. **Affichage des conflits** :
    - Lorsqu'un conflit est détecté, Git vous informe des fichiers concernés et des parties conflictuelles.
    - Vous verrez des marqueurs spéciaux dans le fichier pour indiquer les parties en conflit.

2. **Ouverture du fichier** :
    - Ouvrez le fichier en conflit dans un éditeur de texte.
    - Recherchez les parties conflictuelles marquées par des balises spéciales.
        Les zones en conflits sont situées entre les balises \`<<<<<<<\`, \`=======\`, et \`>>>>>>\`.

3. **Résolution manuelle** :
    - Modifiez le fichier pour résoudre les conflits.
    - Supprimez les balises de conflit et conservez uniquement les parties qui doivent être conservées.

4. **Validation des modifications** :
    - Une fois les conflits résolus, enregistrez le fichier modifié.
    - Utilisez \`git add\` pour marquer le fichier comme résolu.

5. **Finalisation de la fusion** :
    - Après avoir résolu tous les conflits, exécutez \`git commit\` pour finaliser la fusion.
    - Git crée un nouveau commit qui intègre les modifications des deux branches.
        le message du commit par défaut contient des informations sur les conflits résolus.
        Vous n'avez pas besoin de modifier ce message si vous êtes satisfait de la résolution.
        Vous pouvez juste fermer l'éditeur de message de commit pour valider le message par défaut.

#### Exemple d'utilisation

\`\`\`bash
$ git pull origin main
Auto-merging fichier.txt
CONFLICT (content): Merge conflict in fichier.txt
Automatic merge failed; fix conflicts and then commit the result.
\`\`\`

- **Explication** :
    - Git vous informe qu'il y a un conflit dans le fichier \`fichier.txt\`.
    - Vous devez ouvrir ce fichier, résoudre les conflits manuellement, puis valider les modifications.

Contenu du fichier \`fichier.txt\` après un conflit :

\`\`\`
Blabla blabla
<<<<<<< HEAD
JE VEUX RAJOUTER CE TEXTE
=======
QUELQU'UN D'AUTRE A FAIT DES MODIFICATIONS ICI
>>>>>>> main
Blabla blabla
\`\`\`

On voit ici que les parties en conflit sont entourées de balises spéciales. Vous devez choisir quelle partie garder et laquelle supprimer. On peut aussi garder les deux parties, ou les modifier pour obtenir un résultat différent.

Voici un exemple de résolution de conflit :
\`\`\`
Blabla blab
JE VEUX RAJOUTER CE TEXTE et QUELQU'UN D'AUTRE A FAIT DES MODIFICATIONS ICI
Blabla blabla
\`\`\`

Ici, j'ai choisi de garder les deux parties et de les combiner.

Je termine la résolution avec les commandes:
\`\`\`bash
$ git add fichier.txt
$ git commit
[main 6f9d7f5] ....
1 file changed, 1 insertion(+), 1 deletion(-)
\`\`\`

Je quitte l'éditeur qui vient de s'ouvrir ( avec ":wq" sous vim par exemple) et le commit est créé avec le message par défaut.

Je pense à pousser mes modifications avec un \`git push\` pour les partager avec les autres membres de l'équipe.

Pour finir je peux voir les commits en faisant un \`git log\` pour vérifier que tout est bon.
`,

        example: 'git pull origin main',
        result: 'Les modifications de la branche "main" sont fusionnées dans votre branche locale.',
        tag: 'conflits',
    },
    {
        command: ['git init'],
        description: 'Initialiser un nouveau dépôt Git.',
        example: 'git init',
        result: 'Un nouveau dépôt vide Git est initialisé dans le dossier courant.',
        tag: 'avancé',
    },
    {
        command: ['git branch'],
        description: 'Lister toutes les branches locales.',
        example: 'git branch',
        result: 'Affiche toutes les branches locales avec un astérisque (*) devant la branche courante.',
        tag: 'avancé',
    },
    {
        command: ['git checkout <branche>'],
        description: 'Basculer vers une autre branche.',
        example: 'git checkout develop',
        result: 'Vous passez à la branche "develop".',
        tag: 'avancé',
    },
    {
        command: ['git merge <branche>'],
        description: 'Fusionner une branche avec la branche actuelle.',
        example: 'git merge feature-branch',
        result: 'Les modifications de "feature-branch" sont fusionnées dans la branche actuelle.',
        tag: 'avancé',
    },
    {
        command: ['git remote -v'],
        description: 'Afficher les dépôts distants configurés.',
        example: 'git remote -v',
        result: 'Affiche les URL des dépôts distants configurés.',
        tag: 'avancé',
    },
    {
        command: ['git reset --hard'],
        description: 'Réinitialiser l’index et la copie de travail à l’état du dernier commit.',
        example: 'git reset --hard',
        result: 'L’index et la copie de travail sont réinitialisés à l’état du dernier commit.',
        tag: 'avancé',
    },
    {
        command: ['git revert <commit>'],
        description: 'Annuler un commit en créant un nouveau commit inverse.',
        example: 'git revert abc123',
        result: 'Un nouveau commit est créé pour annuler les modifications du commit "abc123".',
        tag: 'avancé',
    },
    {
        command: ['git stash'],
        description: 'Mettre de côté les modifications pour les appliquer plus tard.',
        example: 'git stash',
        result: 'Les modifications locales sont mises de côté dans la pile.',
        tag: 'avancé',
    },
    {
        command: ['git rebase <branche>'],
        description: 'Rejouer les commits de la branche actuelle sur une autre branche.',
        example: 'git rebase main',
        result: 'Les commits de la branche actuelle sont rejoués sur la branche "main".',
        tag: 'avancé',
    },
];
  
export default gitCommands;


export const gitDescription = `
#### Fonctionnement rapide de Git

Git est un système de gestion de versions distribué. Cela signifie que chaque copie locale d'un dépôt contient tout l'historique du projet, ce qui permet de travailler hors ligne. Voici un flux de travail typique avec Git :

1. **Clonage du dépôt** (\`git clone\`) : Télécharge le projet sur votre machine.
2. **Développement** : Modifiez le code, ajoutez des fichiers.
3. **Indexation des modifications** (\`git add\`) : Ajoutez les modifications que vous souhaitez enregistrer.
4. **Validation des modifications** (\`git commit\`) : Sauvegardez les modifications localement avec un message de commit.
5. **Envoi au dépôt distant** (\`git push\`) : Envoyez vos modifications sur GitLab.
6. **Mise à jour locale** (\`git pull\`) : Récupérez les modifications des autres collaborateurs.

#### Pourquoi utiliser Git ?

- **Historique complet** : Garde une trace de toutes les modifications apportées au projet.
- **Collaboration** : Permet à plusieurs personnes de travailler sur le même projet.
- **Sauvegarde** : Protège contre la perte de données en cas de problème.
- **Gestion des versions** : Permet de revenir en arrière ou de comparer les versions.
- **Test et déploiement** : Facilite les tests et le déploiement du code.

`;