import { Title } from "@solidjs/meta";
import { createSignal, For, Show } from 'solid-js';
import Counter from "~/components/Counter";
import gitCommands, { gitDescription } from '~/components/GitCheatSheet';
import { marked } from 'marked';


const App = () => {
  
  const [search, setSearch] = createSignal('');
  const [selectedCommand, setSelectedCommand] = createSignal(null);
  const [tags, setTags] = createSignal('création');

  const filteredCommands = () =>
    gitCommands.filter((cmd) => {
      if(search().trim() == '')
      {
        // Filtrer par tags
        const matchesTags = (!tags() || tags() == cmd.tag);
        return matchesTags;
      }

      // if cmd.command is an array, join it
      let cmd_command = Array.isArray(cmd.command) ? cmd.command.join(' ') : cmd.command;
      // Filtrer par recherche
      const matchesSearch =
        cmd_command.toLowerCase().includes(search().toLowerCase()) ||
        cmd.description.toLowerCase().includes(search().toLowerCase());
  
      return matchesSearch;
    });

  return (
    <div class="container">
            <input
        type="text"
        placeholder="Rechercher une commande..."
        onInput={(e) => setSearch(e.currentTarget.value)}
      />
      <div class="tags">
      {['création', 'basique', 'conflits', 'avancé'].map((tag) => (
        <button
        class={`tag-button ${tag == tags() && search().trim() == '' ? 'active' : ''}`}
        onClick={() => {
              if (tags() !== tag) {
                setTags(tag);
              } else {
                setTags('');
              }
            }}
          >
          {tag}
        </button>
      ))}
    </div>
    
      <div class="commands-list">
        <Show when={filteredCommands().length > 0} fallback={<p>Aucune commande trouvée.</p>}>
          <For each={filteredCommands()}>
            {(cmd) => (
              <>
                <div class="command" onClick={() => {
                  if (selectedCommand() == cmd) {
                    setSelectedCommand(null);
                  } else {
                    setSelectedCommand(cmd);
                  }
                }}>
                  <For each={cmd.command}>
                    {(c, i) => <><code>{c}</code>{ i() < cmd.command.length - 1 ? ' ou ' : null}</>}
                  </For>
                  <p>{cmd.description}</p>
                </div>
                <Show when={selectedCommand() && selectedCommand() == cmd}>
                  <div class="command-details">
                    <h2>Détails de la commande</h2>
                    <p><strong>Commande :</strong> 
                      <For each={cmd.command}>
                        {(c, i) => <><code>{c}</code>{ i() < cmd.command.length - 1 ? ' ou ' : null}</>}
                      </For>
                    </p>
                    <p><strong>Description :</strong> {selectedCommand().description}</p>
                    {selectedCommand().long_description && <p>
                      <strong>Description détaillée :</strong> 
                      <span innerHTML={marked.parse(selectedCommand().long_description)}>
                      </span>
                    </p>}
                    <p><strong>Exemple :</strong> <code>{selectedCommand().example}</code></p>
                    <p><strong>Résultat :</strong> {selectedCommand().result}</p>
                    <button onClick={() => setSelectedCommand(null)}>Fermer</button>
                  </div>
                </Show>
              </>
            )}
          </For>
        </Show>
      </div>

    </div>
  );
};

export default function Home() {
  const [showGitInfo, setShowGitInfo] = createSignal(false);
  return (
    <main>
      <Title>Aide-mémoire Git</Title>
      <h1>Aide-mémoire <span class="git-title">Git</span><span class="info-icon" onClick={() => setShowGitInfo(!showGitInfo())}>
        ?
        </span></h1>
        <Show when={showGitInfo()}>
        <div class="git-info">
          <div class="close-git-info" onclick={() => {setShowGitInfo(false)}}>❌</div>
          <p innerHTML={marked.parse(gitDescription)}>
          </p>
        </div>
      </Show>
      <App />
    </main>
  );
}
